@@ -1,29 +1,25 @@
 package MooX::TypeTiny;
 use strict;
 use warnings;
-our $VERSION = '0.002_000';
+our $VERSION = '0.001000';
 $VERSION =~ tr/_//d;
 
-use Moo::_Utils qw(_install_modifier);
-
 sub import {
   my $target = caller;
   require Moo;
   require Moo::Role;
 
-  unless (Moo->is_class($target)) {
-    die "MooX::TypeTiny can only be used on Moo classes.";
+  unless ($Moo::MAKERS{$target} && $Moo::MAKERS{$target}{is_class}) {
+      die "MooX::TypeTiny can only be used on Moo classes.";
   }
 
-  _install_modifier($target, 'before', ['has', 'extends', 'with'], sub {
-    Moo::Role->apply_roles_to_object(
-      Moo->_accessor_maker_for($target),
-      'MooX::TypeTiny::Role::GenerateAccessor',
-    );
+  Moo::Role->apply_roles_to_object(
+    Moo->_accessor_maker_for($target),
+    'Method::Generate::Accessor::Role::TypeTiny',
+  );
 
-    # make sure we have our own constructor
-    Moo->_constructor_maker_for($target);
-  });
+  # make sure we have our own constructor
+  Moo->_constructor_maker_for($target);
 }
 
 1;
